==> 0.2.4.tar.gz: example/drop/view/board.dart <==
part of drop;

class Board extends Surface {
  static const int pieceCount = 10;
  static const String drop = 'drop';
  static const String count = 'count';
  static const String hitCount = 'hitCount';

  MovablePieces fallingPieces;
  bool isGameOver;
  InputElement pieceCountInput = querySelector('#piece-count');
  LabelElement hitCountLabel = querySelector('#hit-count');

  Board(CanvasElement canvas) : super(canvas) {
    init(pieceCount);
    querySelector('#save').onClick.listen((e) {
      save();
    });
    querySelector('#load').onClick.listen((e) {
      load();
    });
    querySelector('#restart').onClick.listen((e) {
      restart();
    });
    querySelector('#start').onClick.listen((e) {
      start();
    });
    canvas.onMouseDown.listen((MouseEvent e) {
      var x = e.offset.x;
      var y = e.offset.y;
      fallingPieces.forEach((MovablePiece fp) {
        if (fp.contains(x, y)) {
          if (fp.isSelected) {
            fp.isVisible = false;
            var invisibleCount = fallingPieces.invisibleCount();
            hitCountLabel.text = invisibleCount.toString();
            if (invisibleCount == pieceCount) {
              isGameOver = true;
            }
          } else {
            fp.isSelected = true;
          }
        }
      });
    });
  }

  init(int numberOfPieces) {
    fallingPieces = new MovablePieces(numberOfPieces);
    fallingPieces.randomInit();
    fallingPieces.forEach((MovablePiece fp) {
      fp.shape = PieceShape.SQUARE;
      fp.width = fp.height;
      fp.dy = 2;
      fp.minMaxSpace.minArea.width = width;
      fp.minMaxSpace.minArea.height = height;
      fp.minMaxSpace.maxArea.height = height + 200;
    });
    pieceCountInput.value = numberOfPieces.toString();
    hitCountLabel.text = '0';
    isGameOver = false;
  }

  draw() {
    if (!isGameOver) {
      clear();
      fallingPieces.forEach((MovablePiece fp) {
        fp.move(Direction.DOWN);
        if (fp.isVisible) {
          if (fp.isSelected) {
            fp.shape = PieceShape.ROUNDED_RECT;
          }
          drawPiece(fp);
        }
      });
    }
  }

  save() {
    window.localStorage[count] = fallingPieces.length.toString();
    window.localStorage[drop] = fallingPieces.toJsonString();
    window.localStorage[hitCount] = fallingPieces.invisibleCount().toString();
  }

  load() {
    String countString = window.localStorage[count];
    if (countString != null) {
      pieceCountInput.value = countString;
      try {
        init(int.parse(countString));
      } on FormatException catch(e) {
        init(pieceCount);
      }
    } else {
      pieceCountInput.value = pieceCount.toString();
    }
    String gameString = window.localStorage[drop];
    if (gameString != null) {
      fallingPieces.fromJsonString(gameString);
    }
    String hitCountString = window.localStorage[hitCount];
    if (hitCountString != null) {
      hitCountLabel.text = hitCountString;
    } else {
      hitCountLabel.text = '0';
    }
  }

  restart() {
    fallingPieces.forEach((MovablePiece fp) {
      fp.isVisible = true;
      fp.isSelected = false;
      fp.shape = PieceShape.SQUARE;
    });
    hitCountLabel.text = '0';
    isGameOver = false;
  }

  start() {
    try {
      init(int.parse(pieceCountInput.value));
    } on FormatException catch(e) {
      init(pieceCount);
    }
  }
}

==> 0.2.6.tar.gz: example/drop/view/board.dart <==
part of drop;

class Board extends Object with Surface {
  static const int pieceCount = 10;
  static const String drop = 'drop';
  static const String count = 'count';
  static const String hitCount = 'hitCount';

  Pieces fallingPieces;
  bool isGameOver;
  InputElement pieceCountInput = querySelector('#piece-count');
  LabelElement hitCountLabel = querySelector('#hit-count');

  Board(CanvasElement canvas) {
    this.canvas = canvas;
    init(pieceCount);
    querySelector('#save').onClick.listen((e) {
      save();
    });
    querySelector('#load').onClick.listen((e) {
      load();
    });
    querySelector('#restart').onClick.listen((e) {
      restart();
    });
    querySelector('#start').onClick.listen((e) {
      start();
    });
    canvas.onMouseDown.listen((MouseEvent e) {
      var x = e.offset.x;
      var y = e.offset.y;
      fallingPieces.forEach((Piece fp) {
        if (fp.contains(x, y)) {
          if (fp.isSelected) {
            fp.isVisible = false;
            var invisibleCount = fallingPieces.invisibleCount();
            hitCountLabel.text = invisibleCount.toString();
            if (invisibleCount == pieceCount) {
              isGameOver = true;
            }
          } else {
            fp.isSelected = true;
          }
        }
      });
    });
  }

  init(int numberOfPieces) {
    fallingPieces = new Pieces();
    fallingPieces.create(numberOfPieces);
    fallingPieces.randomInit();
    fallingPieces.forEach((Piece fp) {
      fp.shape = PieceShape.SQUARE;
      fp.width = fp.height;
      fp.dy = 2;
      fp.minMaxSpace.minArea.width = width;
      fp.minMaxSpace.minArea.height = height;
      fp.minMaxSpace.maxArea.height = height + 200;
    });
    pieceCountInput.value = numberOfPieces.toString();
    hitCountLabel.text = '0';
    isGameOver = false;
  }

  draw() {
    if (!isGameOver) {
      clear();
      fallingPieces.forEach((Piece fp) {
        fp.move(Direction.DOWN);
        if (fp.isVisible) {
          if (fp.isSelected) {
            fp.shape = PieceShape.ROUNDED_RECT;
          }
          drawPiece(fp);
        }
      });
    }
  }

  save() {
    window.localStorage[count] = fallingPieces.length.toString();
    window.localStorage[drop] = fallingPieces.toJsonString();
    window.localStorage[hitCount] = fallingPieces.invisibleCount().toString();
  }

  load() {
    String countString = window.localStorage[count];
    if (countString != null) {
      pieceCountInput.value = countString;
      try {
        init(int.parse(countString));
      } on FormatException catch(e) {
        init(pieceCount);
      }
    } else {
      pieceCountInput.value = pieceCount.toString();
    }
    String gameString = window.localStorage[drop];
    if (gameString != null) {
      fallingPieces.fromJsonString(gameString);
    }
    String hitCountString = window.localStorage[hitCount];
    if (hitCountString != null) {
      hitCountLabel.text = hitCountString;
    } else {
      hitCountLabel.text = '0';
    }
  }

  restart() {
    fallingPieces.forEach((Piece fp) {
      fp.isVisible = true;
      fp.isSelected = false;
      fp.shape = PieceShape.SQUARE;
    });
    hitCountLabel.text = '0';
    isGameOver = false;
  }

  start() {
    try {
      init(int.parse(pieceCountInput.value));
    } on FormatException catch(e) {
      init(pieceCount);
    }
  }
}
